@@ -159,8 +159,11 @@ class Microservices(BaseClass, ABC):
             self.logs.warn('No se encuentra activado la validacion por redis')
         else:
             port = os.environ.get('REDIS_PORT', 6379)
-            self.redisclient = redis.Redis(
-                host=os.environ.get('REDISVALIDATE'), port=int(port), db=0)
+
+            __pool_redis = redis.ConnectionPool(
+                host=os.environ.get("REDISVALIDATE"), port=int(port), db=0)
+            self.redisclient = redis.Redis(connection_pool=__pool_redis)
+
             if self.redisclient is None:
                 self.logs.warn(
                     'No fue posible conectarse al servidor \
@@ -179,9 +182,9 @@ class Microservices(BaseClass, ABC):
         else:
             h = SHA256.new()
             h.update(bytes(data, 'utf-8'))
-            response_redis = self.redisclient.execute_command(
-                'GETSET', h.hexdigest(), data)
+            response_redis = self.redisclient.getset(h.hexdigest(), data)
             if response_redis is None:
+                self.redisclient.expire(h.hexdigest(), (10 * 60))
                 return False
             return True
 
